@@ -1,13 +1,6 @@
-"""
-Base importer class for the commands to pull in blog posts from other blog 
-platforms into Mezzanine.
-"""
 
-from datetime import datetime, timedelta
-from time import mktime, strftime, strptime, timezone
 from optparse import make_option
 from urlparse import urlparse
-from xml.dom.minidom import parse, parseString
 
 from django.contrib.auth.models import User
 from django.contrib.redirects.models import Redirect
@@ -20,28 +13,28 @@ from mezzanine.core.models import Keyword, CONTENT_STATUS_PUBLISHED
 
 class BaseImporterCommand(BaseCommand):
     """
-    Imports blog posts into Mezzanine from a variety of different sources. 
-    Should be subclasses for a particular blogging platform and have the 
-    ``handle_import`` method overrdden to provide the import mechanism 
-    specific to the blogging platform being dealt with.
+    Base importer command for blogging platform specific management
+    commands to subclass when importing blog posts into Mezzanine.
+    The ``handle_import`` method should be overridden to provide the
+    import mechanism specific to the blogging platform being dealt with.
     """
-    
+
     option_list = BaseCommand.option_list + (
         make_option("-m", "--mezzanine-user", dest="mezzanine_user",
             help="Mezzanine username to assign the imported blog posts to."),
     )
 
-    def __init__ (self, **kwargs):
+    def __init__(self, **kwargs):
         self.posts = []
         super(BaseImporterCommand, self).__init__(**kwargs)
-        
+
     def add_post(self, title=None, pub_date=None, tags=None,
         content=None, comments=None, old_url=None):
         """
         Adds a post to the post list for processing.
-        
+
         Attributes:
-            pub_date is assumed to be a datetime struct
+            pub_date is assumed to be a datetime object.
         """
         if tags is None:
             tags = []
@@ -56,14 +49,14 @@ class BaseImporterCommand(BaseCommand):
             "old_url": old_url,
         })
         return self.posts[-1]
-                
-    def add_comment(self, post=None, name=None, email=None, pub_date=None, 
+
+    def add_comment(self, post=None, name=None, email=None, pub_date=None,
         website=None, body=None):
         """
         Adds a comment to the post provided.
-        
+
         Attributes:
-            pub_date is assumed to be a date time struct
+            pub_date is assumed to be a date time object.
         """
         if post is None:
             if not self.posts:
@@ -76,29 +69,29 @@ class BaseImporterCommand(BaseCommand):
             "website": website,
             "body": body,
         })
-            
+
     def handle(self, *args, **options):
         """
         Processes the converted data into the Mezzanine database correctly.
-        
+
         Attributes:
             mezzanine_user: the user to put this data in against
-            date_format: the format the dates are in in the Posts and Commments
+            date_format: the format the dates are in for posts and comments
         """
 
         mezzanine_user = options.get("mezzanine_user")
         site = Site.objects.get_current()
         verbosity = int(options.get("verbosity", 1))
-        
+
         # Validate the Mezzanine user.
         if mezzanine_user is None:
             raise CommandError("No Mezzanine user has been specified")
         try:
             mezzanine_user = User.objects.get(username=mezzanine_user)
-        except User.DoesNotExist: 
+        except User.DoesNotExist:
             raise CommandError("Invalid Mezzanine user: %s" % mezzanine_user)
-        
-        # Run the subclassed ``handle_import`` and save posts, tags and 
+
+        # Run the subclassed ``handle_import`` and save posts, tags and
         # comments to the DB.
         self.handle_import(options)
         for post in self.posts:
@@ -131,8 +124,8 @@ class BaseImporterCommand(BaseCommand):
 
     def handle_import(self, options):
         """
-        Should be overridden by subclasses - Performs the conversion from 
-        the originating data source into the lists of posts and comments 
+        Should be overridden by subclasses - performs the conversion from
+        the originating data source into the lists of posts and comments
         ready for processing.
         """
         raise NotImplementedError
