@@ -1,45 +1,56 @@
+"""
+Drop-in replacement for ``django.conf.settings`` that provides a
+consistent access method for settings defined in applications, the project
+or Django itself. Settings can also be made editable via the admin.
+"""
 
 from django.conf import settings
 
+from mezzanine import __version__
+
 
 registry = {}
 
 
-def register_setting(name="", editable=False, description="", default=None):
+def register_setting(name="", editable=False, description="", default=None,
+                     append=False):
     """
     Registers a setting that can be edited via the admin.
     """
-    # Check project's settings module for overriden default.
-    default = getattr(settings, name, default)
-    registry[name] = {"name": name, "description": description, "editable":
-        editable, "default": default, "type": type(default)}
+    # Check project's settings module for overridden default.
+    if append and name in registry:
+        registry[name]["default"] += default
+    else:
+        default = getattr(settings, name, default)
+        registry[name] = {"name": name, "description": description,
+            "editable": editable, "default": default, "type": type(default)}
 
 
 class Settings(object):
     """
-    An object that provides settings via dynamic attribute access. Settings 
-    that are registered as editable and can therefore be stored in the 
-    database are *all* loaded once only, the first time *any* editable 
-    setting is accessed. When accessing uneditable settings their default 
-    values are used. The Settings object also provides access to Django 
-    settings via django.conf.settings in order to provide a consistent 
+    An object that provides settings via dynamic attribute access. Settings
+    that are registered as editable and can therefore be stored in the
+    database are *all* loaded once only, the first time *any* editable
+    setting is accessed. When accessing uneditable settings their default
+    values are used. The Settings object also provides access to Django
+    settings via ``django.conf.settings`` in order to provide a consistent
     method of access for all settings.
     """
 
     def __init__(self):
         """
-        Marking loaded as True to begin with prevents some nasty errors 
+        Marking loaded as True to begin with prevents some nasty errors
         when the DB table is first created.
         """
         self._loaded = True
         self._editable_cache = {}
-    
+
     def use_editable(self):
         """
-        Empty the editable settings cache and set the loaded flag to False 
-        so that settings will be loaded from the DB on next access. If the 
-        conf app is not installed then set the loaded flag to True in order 
-        to bypass DB lookup entirely.
+        Empty the editable settings cache and set the loaded flag to
+        ``False`` so that settings will be loaded from the DB on next
+        access. If the conf app is not installed then set the loaded
+        flag to ``True`` in order to bypass DB lookup entirely.
         """
         self._loaded = __name__ not in getattr(self, "INSTALLED_APPS")
         self._editable_cache = {}
@@ -63,6 +74,7 @@ class Settings(object):
                 else:
                     setting_value = setting_type(setting_obj.value)
                 self._editable_cache[setting_obj.name] = setting_value
+            self._loaded = True
 
         # Use cached editable setting if found, otherwise use default.
         try:
@@ -77,7 +89,7 @@ class Settings(object):
 for app in [__name__] + [a for a in settings.INSTALLED_APPS if a != __name__]:
     try:
         __import__("%s.defaults" % app)
-    except ImportError:
+    except (ImportError, ValueError):  # ValueError raised by convert_to_south
         pass
-        
+
 settings = Settings()
